@@ -346,10 +346,9 @@ void KMainWindowPrivate::polish(KMainWindow *q)
     dbusName = QLatin1Char('/') + QCoreApplication::applicationName() + QLatin1Char('/');
     dbusName += q->objectName().replace(QLatin1Char('/'), QLatin1Char('_'));
     // Clean up for dbus usage: any non-alphanumeric char should be turned into '_'
-    const int len = dbusName.length();
-    for (int i = 0; i < len; ++i) {
-        if (!isValidDBusObjectPathCharacter(dbusName[i])) {
-            dbusName[i] = QLatin1Char('_');
+    for (QChar &c : dbusName) {
+        if (!isValidDBusObjectPathCharacter(c)) {
+            c = QLatin1Char('_');
         }
     }
 
@@ -405,7 +404,7 @@ KMainWindow::~KMainWindow()
     delete k_ptr;
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 QMenu *KMainWindow::helpMenu(const QString &aboutAppText, bool showWhatsThis)
 {
     K_D(KMainWindow);
@@ -729,14 +728,14 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
     d->letDirtySettings = oldLetDirtySettings;
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KMainWindow::restoreWindowSize(const KConfigGroup &cg)
 {
     KWindowConfig::restoreWindowSize(windowHandle(), cg);
 }
 #endif
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KMainWindow::saveWindowSize(KConfigGroup &cg) const
 {
     KWindowConfig::saveWindowSize(windowHandle(), cg);
