@@ -95,7 +95,7 @@ public:
     Private(KToolBar *qq)
         : q(qq),
           isMainToolBar(false),
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
           enableContext(true),
 #endif
           unlockedMovable(true),
@@ -152,7 +152,7 @@ public:
 
     KToolBar *q;
     bool isMainToolBar : 1;
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
     bool enableContext : 1;
 #endif
     bool unlockedMovable : 1;
@@ -184,16 +184,16 @@ public:
     public:
         IntSetting()
         {
-            for (int level = 0; level < NSettingLevels; ++level) {
-                values[level] = Unset;
+            for (int &value : values) {
+                value = Unset;
             }
         }
         int currentValue() const
         {
             int val = Unset;
-            for (int level = 0; level < NSettingLevels; ++level) {
-                if (values[level] != Unset) {
-                    val = values[level];
+            for (int value : values) {
+                if (value != Unset) {
+                    val = value;
                 }
             }
             return val;
@@ -213,8 +213,8 @@ public:
         QString toString() const
         {
             QString str;
-            for (int level = 0; level < NSettingLevels; ++level) {
-                str += QString::number(values[level]) + QLatin1Char(' ');
+            for (int value : values) {
+                str += QString::number(value) + QLatin1Char(' ');
             }
             return str;
         }
@@ -320,7 +320,8 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
         contextBottom = contextOrient->addAction(i18nc("toolbar position string", "Bottom"), q, SLOT(slotContextBottom()));
 
         QActionGroup *positionGroup = new QActionGroup(contextOrient);
-        Q_FOREACH (QAction *action, contextOrient->actions()) {
+        const auto orientActions = contextOrient->actions();
+        for (QAction *action : orientActions) {
             action->setActionGroup(positionGroup);
             action->setCheckable(true);
         }
@@ -333,7 +334,8 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
         contextTextUnder = contextMode->addAction(i18n("Text Under Icons"), q, SLOT(slotContextTextUnder()));
 
         QActionGroup *textGroup = new QActionGroup(contextMode);
-        Q_FOREACH (QAction *action, contextMode->actions()) {
+        const auto modeActions = contextMode->actions();
+        for (QAction *action : modeActions) {
             action->setActionGroup(textGroup);
             action->setCheckable(true);
         }
@@ -354,7 +356,7 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
 
         if (avSizes.count() < 10) {
             // Fixed or threshold type icons
-            Q_FOREACH (int it, avSizes) {
+            for (int it : qAsConst(avSizes)) {
                 QString text;
                 if (it < 19) {
                     text = i18n("Small (%1x%2)", it, it);
@@ -373,9 +375,9 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
             // Scalable icons.
             const int progression[] = { 16, 22, 32, 48, 64, 96, 128, 192, 256 };
 
-            for (uint i = 0; i < 9; i++) {
-                Q_FOREACH (int it, avSizes) {
-                    if (it >= progression[ i ]) {
+            for (int p : progression) {
+                for (int it : qAsConst(avSizes)) {
+                    if (it >= p) {
                         QString text;
                         if (it < 19) {
                             text = i18n("Small (%1x%2)", it, it);
@@ -396,7 +398,8 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
         }
 
         QActionGroup *sizeGroup = new QActionGroup(contextSize);
-        Q_FOREACH (QAction *action, contextSize->actions()) {
+        const auto sizeActions = contextSize->actions();
+        for (QAction *action : sizeActions) {
             action->setActionGroup(sizeGroup);
             action->setCheckable(true);
         }
@@ -574,7 +577,7 @@ void KToolBar::Private::applyCurrentSettings()
 
 QAction *KToolBar::Private::findAction(const QString &actionName, KXMLGUIClient **clientOut) const
 {
-    Q_FOREACH (KXMLGUIClient *client, xmlguiClients) {
+    for (KXMLGUIClient *client : xmlguiClients) {
         QAction *action = client->actionCollection()->action(actionName);
         if (action) {
             if (clientOut) {
@@ -844,14 +847,14 @@ KToolBar::~KToolBar()
     delete d;
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KToolBar::setContextMenuEnabled(bool enable)
 {
     d->enableContext = enable;
 }
 #endif
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 bool KToolBar::contextMenuEnabled() const
 {
     return d->enableContext;
@@ -882,7 +885,7 @@ void KToolBar::saveSettings(KConfigGroup &cg)
     }
 }
 
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KToolBar::setXMLGUIClient(KXMLGUIClient *client)
 {
     d->xmlguiClients.clear();
@@ -902,7 +905,7 @@ void KToolBar::removeXMLGUIClient(KXMLGUIClient *client)
 
 void KToolBar::contextMenuEvent(QContextMenuEvent *event)
 {
-#ifndef KXMLGUI_NO_DEPRECATED
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
     if (mainWindow() && d->enableContext) {
         QPointer<KToolBar> guard(this);
         const QPoint globalPos = event->globalPos();
@@ -1096,8 +1099,9 @@ void KToolBar::dragEnterEvent(QDragEnterEvent *event)
 
         stream >> actionNames;
 
-        Q_FOREACH (const QString &actionName, actionNames) {
-            Q_FOREACH (KActionCollection *ac, KActionCollection::allCollections()) {
+        const auto allCollections = KActionCollection::allCollections();
+        for (const QString &actionName : qAsConst(actionNames)) {
+            for (KActionCollection *ac : allCollections) {
                 QAction *newAction = ac->action(actionName);
                 if (newAction) {
                     d->actionsBeingDragged.append(newAction);
@@ -1133,7 +1137,8 @@ void KToolBar::dragMoveEvent(QDragMoveEvent *event)
         if (d->dropIndicatorAction)
             {
                 QAction *overAction = nullptr;
-                Q_FOREACH (QAction *action, actions()) {
+                const auto actions = this->actions();
+                for (QAction *action : actions) {
                     // want to make it feel that half way across an action you're dropping on the other side of it
                     QWidget *widget = widgetForAction(action);
                     if (event->pos().x() < widget->pos().x() + (widget->width() / 2)) {
@@ -1144,9 +1149,9 @@ void KToolBar::dragMoveEvent(QDragMoveEvent *event)
 
                 if (overAction != d->dropIndicatorAction) {
                     // Check to see if the indicator is already in the right spot
-                    int dropIndicatorIndex = actions().indexOf(d->dropIndicatorAction);
-                    if (dropIndicatorIndex + 1 < actions().count()) {
-                        if (actions().at(dropIndicatorIndex + 1) == overAction) {
+                    int dropIndicatorIndex = actions.indexOf(d->dropIndicatorAction);
+                    if (dropIndicatorIndex + 1 < actions.count()) {
+                        if (actions.at(dropIndicatorIndex + 1) == overAction) {
                             break;
                         }
                     } else if (!overAction) {
@@ -1290,7 +1295,8 @@ bool KToolBar::eventFilter(QObject *watched, QEvent *event)
             if (!this->isAncestorOf(ww)) {
                 // New parent is not a subwidget - remove event filter
                 ww->removeEventFilter(this);
-                Q_FOREACH (QWidget *child, ww->findChildren<QWidget *>()) {
+                const auto children = ww->findChildren<QWidget *>();
+                for (QWidget *child : children) {
                     child->removeEventFilter(this);
                 }
             }
@@ -1338,7 +1344,8 @@ void KToolBar::actionEvent(QActionEvent *event)
         if (widget) {
             widget->removeEventFilter(this);
 
-            Q_FOREACH (QWidget *child, widget->findChildren<QWidget *>()) {
+            const auto children = widget->findChildren<QWidget *>();
+            for (QWidget *child : children)  {
                 child->removeEventFilter(this);
             }
         }
@@ -1351,7 +1358,8 @@ void KToolBar::actionEvent(QActionEvent *event)
         if (widget) {
             widget->installEventFilter(this);
 
-            Q_FOREACH (QWidget *child, widget->findChildren<QWidget *>()) {
+            const auto children = widget->findChildren<QWidget *>();
+            for (QWidget *child : children) {
                 child->installEventFilter(this);
             }
             // Center widgets that do not have any use for more space. See bug 165274
@@ -1386,8 +1394,10 @@ void KToolBar::setToolBarsLocked(bool locked)
     if (KToolBar::Private::s_locked != locked) {
         KToolBar::Private::s_locked = locked;
 
-        Q_FOREACH (KMainWindow *mw, KMainWindow::memberList()) {
-            Q_FOREACH (KToolBar *toolbar, mw->findChildren<KToolBar *>()) {
+        const auto windows = KMainWindow::memberList();
+        for (KMainWindow *mw : windows) {
+            const auto toolbars = mw->findChildren<KToolBar *>();
+            for (KToolBar *toolbar : toolbars) {
                 toolbar->d->setLocked(locked);
             }
         }
