@@ -45,11 +45,9 @@ public:
         : m_componentName(QCoreApplication::applicationName()),
           m_actionCollection(nullptr),
           m_parent(nullptr),
-          m_builder(nullptr)
+          m_builder(nullptr),
+          m_textTagNames({ QStringLiteral("text"), QStringLiteral("Text"), QStringLiteral("title") })
     {
-        m_textTagNames.append(QStringLiteral("text"));
-        m_textTagNames.append(QStringLiteral("Text"));
-        m_textTagNames.append(QStringLiteral("title"));
     }
     ~KXMLGUIClientPrivate()
     {
@@ -75,7 +73,7 @@ public:
     KXMLGUIBuilder *m_builder;
     QString m_xmlFile;
     QString m_localXMLFile;
-    QStringList m_textTagNames;
+    const QStringList m_textTagNames;
 
     // Actions to enable/disable on a state change
     QMap<QString, KXMLGUIClient::StateChange> m_actionsStateMap;
@@ -103,7 +101,7 @@ KXMLGUIClient::~KXMLGUIClient()
         d->m_factory->forgetClient(this);
     }
 
-    Q_FOREACH (KXMLGUIClient *client, d->m_children) {
+    for (KXMLGUIClient *client : qAsConst(d->m_children)) {
         if (d->m_factory) {
             d->m_factory->forgetClient(client);
         }
@@ -119,7 +117,7 @@ QAction *KXMLGUIClient::action(const char *name) const
 {
     QAction *act = actionCollection()->action(QLatin1String(name));
     if (!act) {
-        Q_FOREACH (KXMLGUIClient *client, d->m_children) {
+        for (KXMLGUIClient *client : qAsConst(d->m_children)) {
             act = client->actionCollection()->action(QLatin1String(name));
             if (act) {
                 break;
@@ -172,7 +170,7 @@ QString KXMLGUIClient::localXMLFile() const
         return QString();
     }
 
-    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kxmlgui5/") +
+    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kxmlgui5/") +
            componentName() + QLatin1Char('/') + d->m_xmlFile;
 }
 
@@ -232,10 +230,10 @@ void KXMLGUIClient::setXMLFile(const QString &_file, bool merge, bool setXMLDoc)
         const QString filter = componentName() + QLatin1Char('/') + _file;
 
         // files on filesystem
-        allFiles << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kxmlgui5/") + filter); // KF >= 5.1
+        allFiles << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("kxmlgui5/") + filter); // KF >= 5.1
 
         // KF >= 5.4 (resource file)
-        const QString qrcFile(QStringLiteral(":/kxmlgui5/") + filter);
+        const QString qrcFile(QLatin1String(":/kxmlgui5/") + filter);
         if (QFile::exists(qrcFile)) {
             allFiles << qrcFile;
         }
@@ -257,7 +255,7 @@ void KXMLGUIClient::setXMLFile(const QString &_file, bool merge, bool setXMLDoc)
     }
 
     // make sure to merge the settings from any file specified by setLocalXMLFile()
-    if (!d->m_localXMLFile.isEmpty() && !file.endsWith(QStringLiteral("ui_standards.rc"))) {
+    if (!d->m_localXMLFile.isEmpty() && !file.endsWith(QLatin1String("ui_standards.rc"))) {
         const bool exists = QDir::isRelativePath(d->m_localXMLFile) || QFile::exists(d->m_localXMLFile);
         if (exists && !allFiles.contains(d->m_localXMLFile)) {
             allFiles.prepend(d->m_localXMLFile);
@@ -306,7 +304,7 @@ static void propagateTranslationDomain(QDomDocument &doc, const QStringList &tag
             return;
         }
     }
-    foreach (const QString &tagName, tagNames) {
+    for (const QString &tagName : tagNames) {
         QDomNodeList textNodes = base.elementsByTagName(tagName);
         for (int i = 0; i < textNodes.length(); ++i) {
             QDomElement e = textNodes.item(i).toElement();
@@ -756,17 +754,15 @@ KXMLGUIClient::StateChange KXMLGUIClient::getActionsToChangeForState(const QStri
 
 void KXMLGUIClient::stateChanged(const QString &newstate, KXMLGUIClient::ReverseStateChange reverse)
 {
-    StateChange stateChange = getActionsToChangeForState(newstate);
+    const StateChange stateChange = getActionsToChangeForState(newstate);
 
     bool setTrue = (reverse == StateNoReverse);
     bool setFalse = !setTrue;
 
     // Enable actions which need to be enabled...
     //
-    for (QStringList::const_iterator it = stateChange.actionsToEnable.constBegin();
-            it != stateChange.actionsToEnable.constEnd(); ++it) {
-
-        QAction *action = actionCollection()->action(*it);
+    for (const auto &actionId : stateChange.actionsToEnable) {
+        QAction *action = actionCollection()->action(actionId);
         if (action) {
             action->setEnabled(setTrue);
         }
@@ -774,10 +770,8 @@ void KXMLGUIClient::stateChanged(const QString &newstate, KXMLGUIClient::Reverse
 
     // and disable actions which need to be disabled...
     //
-    for (QStringList::const_iterator it = stateChange.actionsToDisable.constBegin();
-            it != stateChange.actionsToDisable.constEnd(); ++it) {
-
-        QAction *action = actionCollection()->action(*it);
+    for (const auto &actionId : stateChange.actionsToDisable) {
+        QAction *action = actionCollection()->action(actionId);
         if (action) {
             action->setEnabled(setFalse);
         }
@@ -788,7 +782,7 @@ void KXMLGUIClient::stateChanged(const QString &newstate, KXMLGUIClient::Reverse
 void KXMLGUIClient::beginXMLPlug(QWidget *w)
 {
     actionCollection()->addAssociatedWidget(w);
-    foreach (KXMLGUIClient *client, d->m_children) {
+    for (KXMLGUIClient *client : qAsConst(d->m_children)) {
         client->beginXMLPlug(w);
     }
 }
@@ -800,7 +794,7 @@ void KXMLGUIClient::endXMLPlug()
 void KXMLGUIClient::prepareXMLUnplug(QWidget *w)
 {
     actionCollection()->removeAssociatedWidget(w);
-    foreach (KXMLGUIClient *client, d->m_children) {
+    for (KXMLGUIClient *client : qAsConst(d->m_children)) {
         client->prepareXMLUnplug(w);
     }
 }
